#!/usr/bin/env python3
"""
novel_downloader.core.exporters.common
--------------------------------------

Shared exporter implementation for producing standard TXT and EPUB outputs.
"""

__all__ = ["CommonExporter"]

from .main_exporter import CommonExporter
